from s.altall import altnews
from s.fbsingle import fb_post
from s.instasingle import insta_post
from s.instaall import insta_profile
from s.goimg import google_image 
from s.trading_image import trade
from s.twsingle import twit_post
from s.wpmsg import whatsapp

